@@ -31,8 +31,7 @@ describe 'nova' do
         :refreshonly => true
       )}
 
-      it 'configures image service' do
-        is_expected.to contain_nova_config('DEFAULT/image_service').with_value('nova.image.glance.GlanceImageService')
+      it 'configures glance api servers' do
         is_expected.to contain_nova_config('glance/api_servers').with_value('http://localhost:9292')
       end
 
@@ -53,7 +52,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('60')
         is_expected.to contain_nova_config('DEFAULT/rootwrap_config').with_value('/etc/nova/rootwrap.conf')
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('10')
-        is_expected.to contain_nova_config('os_vif_linux_bridge/use_ipv6').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/ovsdb_connection').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
@@ -78,7 +76,7 @@ describe 'nova' do
 
       let :params do
         {
-          :image_service                           => 'nova.image.local.LocalImageService',
+          :glance_api_servers                      => 'http://localhost:9292',
           :default_transport_url                   => 'rabbit://rabbit_user:password@localhost:5673',
           :rpc_response_timeout                    => '30',
           :control_exchange                        => 'nova',
@@ -94,7 +92,6 @@ describe 'nova' do
           :notification_driver                     => 'ceilometer.compute.nova_notifier',
           :notification_topics                     => 'openstack',
           :notification_format                     => 'unversioned',
-          :notify_on_api_faults                    => true,
           :report_interval                         => '60',
           :os_region_name                          => 'MyRegion',
           :ovsdb_connection                        => 'tcp:127.0.0.1:6640',
@@ -129,9 +126,8 @@ describe 'nova' do
         })
       end
 
-      it 'configures image service' do
-        is_expected.to contain_nova_config('DEFAULT/image_service').with_value('nova.image.local.LocalImageService')
-        is_expected.to_not contain_nova_config('glance/api_servers')
+      it 'configures glance api servers' do
+        is_expected.to contain_nova_config('glance/api_servers')
       end
 
       it 'configures auth_strategy' do
@@ -176,7 +172,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('oslo_messaging_notifications/driver').with_value('ceilometer.compute.nova_notifier')
         is_expected.to contain_nova_config('oslo_messaging_notifications/topics').with_value('openstack')
         is_expected.to contain_nova_config('notifications/notification_format').with_value('unversioned')
-        is_expected.to contain_nova_config('notifications/notify_on_api_faults').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('60')
         is_expected.to contain_nova_config('DEFAULT/ovsdb_connection').with_value('tcp:127.0.0.1:6640')
         is_expected.to contain_nova_config('os_vif_linux_bridge/use_ipv6').with_value('true')
@@ -220,17 +215,6 @@ describe 'nova' do
       end
     end
 
-    context 'with deprecated notify_api_faults parameter' do
-      let :params do
-        { :notify_on_api_faults => :undef,
-          :notify_api_faults    => 'true' }
-      end
-
-      it 'configures notify_on_api_faults using the deprecated parameter' do
-        is_expected.to contain_nova_config('notifications/notify_on_api_faults').with_value('true')
-      end
-    end
-
     context 'with kombu_reconnect_delay set to 5.0' do
       let :params do
         { :kombu_reconnect_delay => '5.0' }
